Index
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
A
- addFormatters(FormatterRegistry) - Method in class com.bld.crypto.aes.config.AesFormatterConfiguration
-
Adds the formatters.
- addFormatters(FormatterRegistry) - Method in class com.bld.crypto.hmac.config.HmacFormatterConfiguration
- addFormatters(FormatterRegistry) - Method in class com.bld.crypto.jks.config.JksFormatterConfiguration
-
Adds the formatters.
- addFormatters(FormatterRegistry) - Method in class com.bld.crypto.pkcs12.config.Pkcs12FormatterConfiguration
-
Registers the
CryptoPkcs12AnnotationFormatterFactorywith the MVC formatter registry. - addFormatters(FormatterRegistry) - Method in class com.bld.crypto.pubkey.config.PubKeyFormatterConfiguration
-
Adds the formatters.
- addPublicKey(String, String, InstanceType) - Method in class com.bld.crypto.pubkey.config.data.CipherPublicKeys
- addPublicKey(String, PublicKey) - Method in class com.bld.crypto.pubkey.config.data.CipherPublicKeys
- Aes - Class in com.bld.crypto.aes.config.data
-
The Class Aes.
- Aes() - Constructor for class com.bld.crypto.aes.config.data.Aes
- AES - Enum constant in enum class com.bld.crypto.type.InstanceType
-
Advanced Encryption Standard symmetric algorithm.
- AesConditional - Class in com.bld.crypto.aes.config
-
The Class PubKeyConditional.
- AesConditional() - Constructor for class com.bld.crypto.aes.config.AesConditional
- AesConfiguration - Class in com.bld.crypto.aes.config
-
The Class AesConfiguration.
- AesConfiguration() - Constructor for class com.bld.crypto.aes.config.AesConfiguration
- AesFormatterConfiguration - Class in com.bld.crypto.aes.config
-
The Class AesFormatterConfiguration.
- AesFormatterConfiguration() - Constructor for class com.bld.crypto.aes.config.AesFormatterConfiguration
- AesProperties - Class in com.bld.crypto.aes.config.data
-
The Class AesProperties.
- AesProperties(Map<String, Aes>) - Constructor for class com.bld.crypto.aes.config.data.AesProperties
-
Instantiates a new aes properties.
- AesSizeType - Enum Class in com.bld.crypto.type
-
Enumeration of the valid AES key sizes in bytes.
B
- BEARER - Static variable in class com.bld.crypto.jks.CryptoJksUtils
-
The Constant BEARER.
C
- CipherAesSecret - Class in com.bld.crypto.aes.config.data
-
The Class CipherAesSecret.
- CipherAesSecret(Map<String, SecretKey>) - Constructor for class com.bld.crypto.aes.config.data.CipherAesSecret
-
Instantiates a new cipher aes secret.
- CipherPublicKeys - Class in com.bld.crypto.pubkey.config.data
-
The Class CipherPublicKeys.
- CipherPublicKeys() - Constructor for class com.bld.crypto.pubkey.config.data.CipherPublicKeys
-
Instantiates a new cipher public keys.
- com.bld.crypto.aes - package com.bld.crypto.aes
- com.bld.crypto.aes.annotation - package com.bld.crypto.aes.annotation
- com.bld.crypto.aes.config - package com.bld.crypto.aes.config
- com.bld.crypto.aes.config.data - package com.bld.crypto.aes.config.data
- com.bld.crypto.aes.deserializer - package com.bld.crypto.aes.deserializer
- com.bld.crypto.aes.formatter - package com.bld.crypto.aes.formatter
- com.bld.crypto.aes.serializer - package com.bld.crypto.aes.serializer
- com.bld.crypto.bean - package com.bld.crypto.bean
- com.bld.crypto.commons - package com.bld.crypto.commons
- com.bld.crypto.config - package com.bld.crypto.config
- com.bld.crypto.config.annotation - package com.bld.crypto.config.annotation
- com.bld.crypto.deserializer - package com.bld.crypto.deserializer
- com.bld.crypto.exception - package com.bld.crypto.exception
- com.bld.crypto.formatter - package com.bld.crypto.formatter
- com.bld.crypto.hmac - package com.bld.crypto.hmac
- com.bld.crypto.hmac.annotation - package com.bld.crypto.hmac.annotation
- com.bld.crypto.hmac.config - package com.bld.crypto.hmac.config
- com.bld.crypto.hmac.config.data - package com.bld.crypto.hmac.config.data
- com.bld.crypto.hmac.deserializer - package com.bld.crypto.hmac.deserializer
- com.bld.crypto.hmac.formatter - package com.bld.crypto.hmac.formatter
- com.bld.crypto.hmac.serializer - package com.bld.crypto.hmac.serializer
- com.bld.crypto.jks - package com.bld.crypto.jks
- com.bld.crypto.jks.annotation - package com.bld.crypto.jks.annotation
- com.bld.crypto.jks.config - package com.bld.crypto.jks.config
- com.bld.crypto.jks.config.properties - package com.bld.crypto.jks.config.properties
- com.bld.crypto.jks.deserializer - package com.bld.crypto.jks.deserializer
- com.bld.crypto.jks.formatter - package com.bld.crypto.jks.formatter
- com.bld.crypto.jks.serializer - package com.bld.crypto.jks.serializer
- com.bld.crypto.key - package com.bld.crypto.key
- com.bld.crypto.openapi - package com.bld.crypto.openapi
- com.bld.crypto.pkcs12 - package com.bld.crypto.pkcs12
- com.bld.crypto.pkcs12.annotation - package com.bld.crypto.pkcs12.annotation
- com.bld.crypto.pkcs12.config - package com.bld.crypto.pkcs12.config
- com.bld.crypto.pkcs12.config.properties - package com.bld.crypto.pkcs12.config.properties
- com.bld.crypto.pkcs12.deserializer - package com.bld.crypto.pkcs12.deserializer
- com.bld.crypto.pkcs12.formatter - package com.bld.crypto.pkcs12.formatter
- com.bld.crypto.pkcs12.serializer - package com.bld.crypto.pkcs12.serializer
- com.bld.crypto.pubkey - package com.bld.crypto.pubkey
- com.bld.crypto.pubkey.annotations - package com.bld.crypto.pubkey.annotations
- com.bld.crypto.pubkey.config - package com.bld.crypto.pubkey.config
- com.bld.crypto.pubkey.config.data - package com.bld.crypto.pubkey.config.data
- com.bld.crypto.pubkey.deserializer - package com.bld.crypto.pubkey.deserializer
- com.bld.crypto.pubkey.formatter - package com.bld.crypto.pubkey.formatter
- com.bld.crypto.pubkey.serializer - package com.bld.crypto.pubkey.serializer
- com.bld.crypto.serializer - package com.bld.crypto.serializer
- com.bld.crypto.signature - package com.bld.crypto.signature
- com.bld.crypto.signature.config - package com.bld.crypto.signature.config
- com.bld.crypto.signature.config.properties - package com.bld.crypto.signature.config.properties
- com.bld.crypto.type - package com.bld.crypto.type
- createContextual(DeserializationContext, BeanProperty) - Method in class com.bld.crypto.aes.deserializer.DecryptAesDeserializer
-
Creates the contextual.
- createContextual(DeserializationContext, BeanProperty) - Method in class com.bld.crypto.hmac.deserializer.DecryptHmacDeserializer
- createContextual(DeserializationContext, BeanProperty) - Method in class com.bld.crypto.jks.deserializer.DecryptJksDeserializer
-
Creates the contextual.
- createContextual(DeserializationContext, BeanProperty) - Method in class com.bld.crypto.pkcs12.deserializer.DecryptPkcs12Deserializer
-
Resolves the
CryptoPkcs12annotation and returns a contextual deserializer typed to the target field. - createContextual(DeserializationContext, BeanProperty) - Method in class com.bld.crypto.pubkey.deserializer.DecryptPubKeyDeserializer
-
Creates the contextual.
- createContextual(SerializerProvider, BeanProperty) - Method in class com.bld.crypto.aes.serializer.EncryptAesSerializer
-
Creates the contextual.
- createContextual(SerializerProvider, BeanProperty) - Method in class com.bld.crypto.hmac.serializer.EncryptHmacSerializer
- createContextual(SerializerProvider, BeanProperty) - Method in class com.bld.crypto.jks.serializer.EncryptJksSerializer
-
Creates the contextual.
- createContextual(SerializerProvider, BeanProperty) - Method in class com.bld.crypto.pkcs12.serializer.EncryptPkcs12Serializer
-
Resolves the
CryptoPkcs12annotation from the current bean property and returns a properly typed contextual serializer. - createContextual(SerializerProvider, BeanProperty) - Method in class com.bld.crypto.pubkey.serializer.EncryptPubKeySerializer
-
Creates the contextual.
- CryptoAes - Annotation Interface in com.bld.crypto.aes.annotation
-
The Interface CryptoJks.
- CryptoAesAnnotationFormatterFactory - Class in com.bld.crypto.aes.formatter
-
A factory for creating CryptoAesAnnotationFormatter objects.
- CryptoAesAnnotationFormatterFactory(CryptoAesUtils, ObjectMapper) - Constructor for class com.bld.crypto.aes.formatter.CryptoAesAnnotationFormatterFactory
-
Instantiates a new crypto aes annotation formatter factory.
- CryptoAesFormatter<T> - Class in com.bld.crypto.aes.formatter
-
The Class CryptoAesFormatter.
- CryptoAesFormatter(ObjectMapper, Class<T>, CryptoAes, CryptoAesUtils) - Constructor for class com.bld.crypto.aes.formatter.CryptoAesFormatter
-
Instantiates a new crypto aes formatter.
- CryptoAesUtils - Class in com.bld.crypto.aes
-
The Class CryptoAesUtils.
- CryptoAesUtils() - Constructor for class com.bld.crypto.aes.CryptoAesUtils
- CryptoConfiguration - Class in com.bld.crypto.config
-
Root Spring configuration class for the
common-encryptionmodule. - CryptoConfiguration() - Constructor for class com.bld.crypto.config.CryptoConfiguration
- CryptoException - Exception Class in com.bld.crypto.exception
-
Unchecked exception thrown whenever a cryptographic operation fails inside the
common-encryptionmodule. - CryptoException() - Constructor for exception class com.bld.crypto.exception.CryptoException
-
Constructs a new
CryptoExceptionwith no detail message. - CryptoException(String) - Constructor for exception class com.bld.crypto.exception.CryptoException
-
Constructs a new
CryptoExceptionwith the specified detail message. - CryptoException(String, Throwable) - Constructor for exception class com.bld.crypto.exception.CryptoException
-
Constructs a new
CryptoExceptionwith the specified detail message and cause. - CryptoException(String, Throwable, boolean, boolean) - Constructor for exception class com.bld.crypto.exception.CryptoException
-
Constructs a new
CryptoExceptionwith the specified detail message, cause, suppression flag, and writable stack trace flag. - CryptoException(Throwable) - Constructor for exception class com.bld.crypto.exception.CryptoException
-
Constructs a new
CryptoExceptionwith the specified cause. - CryptoFormatter<T> - Class in com.bld.crypto.formatter
-
Abstract Spring
Formatterthat encrypts a value onCryptoFormatter.print(Object, Locale)and decrypts it onCryptoFormatter.parse(String, java.util.Locale). - CryptoFormatter(ObjectMapper, Class<T>) - Constructor for class com.bld.crypto.formatter.CryptoFormatter
-
Constructs a new
CryptoFormatter. - CryptoHmac - Annotation Interface in com.bld.crypto.hmac.annotation
-
Field-level annotation that transparently signs a value on Jackson serialisation and verifies it on deserialisation using HMAC.
- CryptoHmacAnnotationFormatterFactory - Class in com.bld.crypto.hmac.formatter
-
AnnotationFormatterFactorythat createsCryptoHmacFormatterinstances for fields annotated withCryptoHmac. - CryptoHmacAnnotationFormatterFactory(CryptoHmacUtils, ObjectMapper) - Constructor for class com.bld.crypto.hmac.formatter.CryptoHmacAnnotationFormatterFactory
- CryptoHmacFormatter<T> - Class in com.bld.crypto.hmac.formatter
-
Spring
Formatterthat signs a field value onprintand verifies it onparseusing HMAC, enabling transparent HMAC authentication for Spring MVC request parameters and path variables. - CryptoHmacFormatter(ObjectMapper, Class<T>, CryptoHmac, CryptoHmacUtils) - Constructor for class com.bld.crypto.hmac.formatter.CryptoHmacFormatter
- CryptoHmacSecret - Class in com.bld.crypto.hmac.config.data
-
Holder for the HMAC
SecretKeyand algorithm name produced byHmacConfiguration. - CryptoHmacSecret(SecretKey, String) - Constructor for class com.bld.crypto.hmac.config.data.CryptoHmacSecret
- CryptoHmacUtils - Class in com.bld.crypto.hmac
-
Utility bean that signs and verifies values using HMAC.
- CryptoHmacUtils() - Constructor for class com.bld.crypto.hmac.CryptoHmacUtils
- CryptoJks - Annotation Interface in com.bld.crypto.jks.annotation
-
The Interface CryptoJks.
- CryptoJksAnnotationFormatterFactory - Class in com.bld.crypto.jks.formatter
-
A factory for creating CryptoJksAnnotationFormatter objects.
- CryptoJksAnnotationFormatterFactory(CryptoJksUtils, ObjectMapper) - Constructor for class com.bld.crypto.jks.formatter.CryptoJksAnnotationFormatterFactory
-
Instantiates a new crypto jks annotation formatter factory.
- CryptoJksConfiguration - Class in com.bld.crypto.jks.config
-
The Class EnableCryptoJksConfiguration.
- CryptoJksConfiguration() - Constructor for class com.bld.crypto.jks.config.CryptoJksConfiguration
- CryptoJksFormatter<T> - Class in com.bld.crypto.jks.formatter
-
The Class CryptoJksFormatter.
- CryptoJksFormatter(CryptoJks, CryptoJksUtils, ObjectMapper, Class<T>) - Constructor for class com.bld.crypto.jks.formatter.CryptoJksFormatter
-
Instantiates a new crypto jks formatter.
- CryptoJksUtils - Class in com.bld.crypto.jks
-
The Class CryptoJksUtils.
- CryptoJksUtils(JksKey) - Constructor for class com.bld.crypto.jks.CryptoJksUtils
- CryptoKeyData - Class in com.bld.crypto.bean
-
Data transfer object that carries the key name and the URL-encoding flag used by serializers and deserializers to locate the correct cryptographic key and to decide whether the encrypted payload must be further Base64-encoded for safe embedding in a URL.
- CryptoKeyData(String, boolean) - Constructor for class com.bld.crypto.bean.CryptoKeyData
-
Constructs a new
CryptoKeyDatainstance. - CryptoKeyUtils - Class in com.bld.crypto.bean
-
Abstract base class that provides low-level encrypt/decrypt operations using the Java
CipherAPI. - CryptoKeyUtils() - Constructor for class com.bld.crypto.bean.CryptoKeyUtils
- CryptoMapPublicKeyUtils - Class in com.bld.crypto.pubkey
-
The Class CryptoMapPublicKeyUtils.
- CryptoMapPublicKeyUtils(CipherPublicKeys) - Constructor for class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
- CryptoModelConverter - Class in com.bld.crypto.openapi
-
SpringDoc/OpenAPI
ModelConverterthat overrides the schema type tostringfor fields annotated with any crypto annotation (@CryptoJks,@CryptoAes,@CryptoPkcs12,@CryptoHmac,@CryptoPubKey). - CryptoModelConverter() - Constructor for class com.bld.crypto.openapi.CryptoModelConverter
- CryptoPkcs12 - Annotation Interface in com.bld.crypto.pkcs12.annotation
-
Field-level annotation that transparently encrypts a value on Jackson serialisation and decrypts it on deserialisation using the X25519 + AES-256-GCM hybrid scheme provided by
CryptoPkcs12Utils. - CryptoPkcs12AnnotationFormatterFactory - Class in com.bld.crypto.pkcs12.formatter
-
Spring
AnnotationFormatterFactorythat registersCryptoPkcs12Formatterfor fields annotated withCryptoPkcs12. - CryptoPkcs12AnnotationFormatterFactory(CryptoPkcs12Utils, ObjectMapper) - Constructor for class com.bld.crypto.pkcs12.formatter.CryptoPkcs12AnnotationFormatterFactory
-
Constructs a new factory with the required dependencies.
- CryptoPkcs12Configuration - Class in com.bld.crypto.pkcs12.config
-
Spring
Configurationthat creates theCryptoPkcs12Utilsbean when the propertycom.bld.crypto.pkcs12.fileis present in the application context. - CryptoPkcs12Configuration() - Constructor for class com.bld.crypto.pkcs12.config.CryptoPkcs12Configuration
- CryptoPkcs12Formatter<T> - Class in com.bld.crypto.pkcs12.formatter
-
Spring
Formatterthat encrypts a field value onprintand decrypts it onparseusing the X25519 + AES-256-GCM scheme, enabling transparent PKCS12 encryption for Spring MVC request parameters. - CryptoPkcs12Formatter(CryptoPkcs12, CryptoPkcs12Utils, ObjectMapper, Class<T>) - Constructor for class com.bld.crypto.pkcs12.formatter.CryptoPkcs12Formatter
-
Constructs a new
CryptoPkcs12Formatter. - CryptoPkcs12Utils - Class in com.bld.crypto.pkcs12
-
Utility class that provides hybrid asymmetric/symmetric encryption and decryption using X25519 (XDH) Elliptic-Curve Diffie-Hellman key agreement combined with AES-256-GCM authenticated encryption.
- CryptoPkcs12Utils(JksKey) - Constructor for class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Constructs a new
CryptoPkcs12Utilswrapping the given key pair. - CryptoPubKey - Annotation Interface in com.bld.crypto.pubkey.annotations
-
The Interface CryptoPubKey.
- CryptoPubKeyAnnotationFormatterFactory - Class in com.bld.crypto.pubkey.formatter
-
A factory for creating CryptoPubKeyAnnotationFormatter objects.
- CryptoPubKeyAnnotationFormatterFactory(CryptoMapPublicKeyUtils, ObjectMapper) - Constructor for class com.bld.crypto.pubkey.formatter.CryptoPubKeyAnnotationFormatterFactory
-
Instantiates a new crypto pub key annotation formatter factory.
- CryptoPubKeyFormatter<T> - Class in com.bld.crypto.pubkey.formatter
-
The Class CryptoPubKeyFormatter.
- CryptoPubKeyFormatter(ObjectMapper, Class<T>, CryptoPubKey, CryptoMapPublicKeyUtils) - Constructor for class com.bld.crypto.pubkey.formatter.CryptoPubKeyFormatter
-
Instantiates a new crypto pub key formatter.
- CryptoPublicKeyConfiguration - Class in com.bld.crypto.pubkey.config
-
The Class EnableCryptoPublicKeyConfiguration.
- CryptoPublicKeyConfiguration() - Constructor for class com.bld.crypto.pubkey.config.CryptoPublicKeyConfiguration
- CryptoPublicKeyUtils - Class in com.bld.crypto.pubkey
-
The Class CryptoMapPublicKeyUtils.
- CryptoPublicKeyUtils(String, InstanceType) - Constructor for class com.bld.crypto.pubkey.CryptoPublicKeyUtils
- CryptoPublicKeyUtils(PublicKey) - Constructor for class com.bld.crypto.pubkey.CryptoPublicKeyUtils
- CryptoSwaggerAutoConfiguration - Class in com.bld.crypto.config
-
Auto-configuration that registers
CryptoModelConverteras a Spring bean whenswagger-core-jakartais present on the classpath. - CryptoSwaggerAutoConfiguration() - Constructor for class com.bld.crypto.config.CryptoSwaggerAutoConfiguration
- CryptoType - Enum Class in com.bld.crypto.type
-
Enumeration that selects which key of an asymmetric key pair (private or public) is used for a specific cryptographic operation in the JKS strategy.
- CryptoUtils - Class in com.bld.crypto.bean
-
Abstract marker base class for crypto utility types.
- CryptoUtils() - Constructor for class com.bld.crypto.bean.CryptoUtils
D
- decrypt() - Element in annotation interface com.bld.crypto.jks.annotation.CryptoJks
-
Decrypt.
- decrypt(String) - Method in class com.bld.crypto.aes.deserializer.DecryptAesDeserializer
-
Decrypt.
- decrypt(String) - Method in class com.bld.crypto.aes.formatter.CryptoAesFormatter
-
Decrypt.
- decrypt(String) - Method in class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
Decrypts the given cipher-text string.
- decrypt(String) - Method in class com.bld.crypto.formatter.CryptoFormatter
-
Decrypts the given cipher-text word using the concrete decryption strategy.
- decrypt(String) - Method in class com.bld.crypto.hmac.deserializer.DecryptHmacDeserializer
- decrypt(String) - Method in class com.bld.crypto.hmac.formatter.CryptoHmacFormatter
- decrypt(String) - Method in class com.bld.crypto.jks.deserializer.DecryptJksDeserializer
-
Decrypt.
- decrypt(String) - Method in class com.bld.crypto.jks.formatter.CryptoJksFormatter
-
Decrypt.
- decrypt(String) - Method in class com.bld.crypto.pkcs12.deserializer.DecryptPkcs12Deserializer
-
Decrypts the cipher text, validates the key envelope, and returns the plain-text value.
- decrypt(String) - Method in class com.bld.crypto.pkcs12.formatter.CryptoPkcs12Formatter
-
Decrypts the given cipher text using the PKCS12 private key.
- decrypt(String) - Method in class com.bld.crypto.pubkey.deserializer.DecryptPubKeyDeserializer
-
Decrypt.
- decrypt(String) - Method in class com.bld.crypto.pubkey.formatter.CryptoPubKeyFormatter
-
Decrypt.
- DecryptAesDeserializer<T> - Class in com.bld.crypto.aes.deserializer
-
The Class UpperLowerDeserializer.
- DecryptAesDeserializer() - Constructor for class com.bld.crypto.aes.deserializer.DecryptAesDeserializer
-
Instantiates a new upper lower deserializer.
- DecryptCertificateDeserializer<T> - Class in com.bld.crypto.deserializer
-
Abstract Jackson
StdScalarDeserializerthat decrypts a JSON string field before converting it to the target Java type. - DecryptCertificateDeserializer(JavaType, ObjectMapper) - Constructor for class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
Constructs a new deserializer for the given
JavaTypewith an explicitObjectMapper. - DecryptCertificateDeserializer(JavaType, Class<?>, ObjectMapper) - Constructor for class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
Constructs a new deserializer for a
Collectionfield. - DecryptCertificateDeserializer(Class<?>) - Constructor for class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
Constructs a new deserializer for the given raw type.
- DecryptHmacDeserializer<T> - Class in com.bld.crypto.hmac.deserializer
-
Jackson
ContextualDeserializerthat verifies an HMAC token and converts the extracted plain-text value to the target Java type. - DecryptHmacDeserializer() - Constructor for class com.bld.crypto.hmac.deserializer.DecryptHmacDeserializer
- DecryptJksDeserializer<T> - Class in com.bld.crypto.jks.deserializer
-
The Class UpperLowerDeserializer.
- DecryptJksDeserializer() - Constructor for class com.bld.crypto.jks.deserializer.DecryptJksDeserializer
-
Instantiates a new upper lower deserializer.
- decryptObject(String, Class<T>) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt object.
- decryptObject(String, Class<T>) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Decrypts an encrypted string and deserialises the JSON result into the target type.
- decryptObject(String, Class<T>) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Decrypt object.
- decryptObject(String, Class<T>, CryptoType) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt object.
- decryptObject(String, Class<T>, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Decrypt object.
- decryptObjectUri(String, Class<T>) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt object uri.
- decryptObjectUri(String, Class<T>) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
URL-decodes, decrypts, and deserialises an encrypted object string.
- decryptObjectUri(String, Class<T>) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Decrypt object uri.
- decryptObjectUri(String, Class<T>, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Decrypt object uri.
- DecryptPkcs12Deserializer<T> - Class in com.bld.crypto.pkcs12.deserializer
-
Jackson
ContextualDeserializerthat decrypts a JSON string field before converting it to the target Java type, using the X25519 + AES-256-GCM scheme. - DecryptPkcs12Deserializer() - Constructor for class com.bld.crypto.pkcs12.deserializer.DecryptPkcs12Deserializer
-
No-arg constructor required by Jackson when Spring injection is used.
- DecryptPubKey - Annotation Interface in com.bld.crypto.pubkey.annotations
-
The Interface DecryptPubKey.
- DecryptPubKeyDeserializer<T> - Class in com.bld.crypto.pubkey.deserializer
-
The Class UpperLowerDeserializer.
- DecryptPubKeyDeserializer() - Constructor for class com.bld.crypto.pubkey.deserializer.DecryptPubKeyDeserializer
-
Instantiates a new upper lower deserializer.
- decryptUri(String) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt uri.
- decryptUri(String) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Removes the outer URL-safe Base64 layer and decrypts the inner cipher text.
- decryptUri(String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Decrypt uri.
- decryptUri(String, CryptoType) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt uri.
- decryptUri(String, String) - Method in class com.bld.crypto.aes.CryptoAesUtils
-
Decrypt uri.
- decryptUri(String, String) - Method in class com.bld.crypto.bean.CryptoKeyUtils
-
Decodes the outer URL-safe Base64 layer and then decrypts the inner cipher text using the named key.
- decryptUri(String, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Decrypt uri.
- decryptUri(String, String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Decrypt uri.
- decryptValue(String) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt value.
- decryptValue(String) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Decrypts a previously encrypted value using the recipient's X25519 private key.
- decryptValue(String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Decrypt value.
- decryptValue(String, CryptoType) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt value.
- decryptValue(String, String) - Method in class com.bld.crypto.aes.CryptoAesUtils
-
Decrypt value.
- decryptValue(String, String) - Method in class com.bld.crypto.bean.CryptoKeyUtils
-
Decrypts a Base64-encoded cipher text using the named key.
- decryptValue(String, String) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Decrypt value.
- decryptValue(String, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Decrypt value.
- decryptValue(String, String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Decrypt value.
- decryptValue(String, Key, InstanceType) - Method in class com.bld.crypto.bean.CryptoKeyUtils
-
Decrypts a Base64-encoded cipher-text string using the supplied key and algorithm.
- deserialize(JsonParser, DeserializationContext) - Method in class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
Deserialize.
E
- EC - Enum constant in enum class com.bld.crypto.type.InstanceType
-
Elliptic Curve algorithm.
- EnableCrypto - Annotation Interface in com.bld.crypto.config.annotation
-
Meta-annotation that activates the
common-encryptionmodule. - encodeValue(String) - Method in class com.bld.crypto.bean.CryptoKeyUtils
-
Applies an additional Base64 encoding to an already-encrypted value, making it safe for embedding in a URL.
- encrypt() - Element in annotation interface com.bld.crypto.jks.annotation.CryptoJks
-
Encrypt.
- EncryptAesSerializer<T> - Class in com.bld.crypto.aes.serializer
-
The Class EncryptPubKeySerializer.
- EncryptAesSerializer() - Constructor for class com.bld.crypto.aes.serializer.EncryptAesSerializer
-
Instantiates a new encrypt pub key serializer.
- EncryptCertificateSerializer<T> - Class in com.bld.crypto.serializer
-
Abstract Jackson
StdScalarSerializerthat encrypts a field value before writing it to the JSON output stream. - EncryptCertificateSerializer(Class<T>) - Constructor for class com.bld.crypto.serializer.EncryptCertificateSerializer
-
Constructs a new serializer for the given type.
- EncryptCertificateSerializer(Class<T>, ObjectMapper) - Constructor for class com.bld.crypto.serializer.EncryptCertificateSerializer
-
Constructs a new serializer for the given type with an explicit
ObjectMapper. - EncryptHmacSerializer<T> - Class in com.bld.crypto.hmac.serializer
-
Jackson
ContextualSerializerthat signs a field value before writing it to the JSON output stream using HMAC. - EncryptHmacSerializer() - Constructor for class com.bld.crypto.hmac.serializer.EncryptHmacSerializer
- EncryptJksSerializer<T> - Class in com.bld.crypto.jks.serializer
-
The Class EncryptJksSerializer.
- EncryptJksSerializer() - Constructor for class com.bld.crypto.jks.serializer.EncryptJksSerializer
-
Instantiates a new encrypt jks serializer.
- encryptObject(Object) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt object.
- encryptObject(Object) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Serialises
valueto JSON and encrypts it. - encryptObject(Object) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Encrypt object.
- encryptObject(Object, CryptoType) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt object.
- encryptObject(Object, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Encrypt object.
- encryptObjectUri(Object) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt object uri.
- encryptObjectUri(Object) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Serialises
valueto JSON, encrypts it, and URL-encodes the result. - encryptObjectUri(Object) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Encrypt object uri.
- encryptObjectUri(Object, CryptoType) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt object uri.
- encryptObjectUri(Object, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Encrypt object uri.
- EncryptPkcs12Serializer<T> - Class in com.bld.crypto.pkcs12.serializer
-
Jackson
ContextualSerializerthat encrypts a field value before writing it to the JSON output stream using the X25519 + AES-256-GCM scheme. - EncryptPkcs12Serializer() - Constructor for class com.bld.crypto.pkcs12.serializer.EncryptPkcs12Serializer
-
No-arg constructor required by Jackson when Spring injection is used.
- EncryptPubKey - Annotation Interface in com.bld.crypto.pubkey.annotations
-
The Interface EncryptPubKey.
- EncryptPubKeySerializer<T> - Class in com.bld.crypto.pubkey.serializer
-
The Class EncryptPubKeySerializer.
- EncryptPubKeySerializer() - Constructor for class com.bld.crypto.pubkey.serializer.EncryptPubKeySerializer
-
Instantiates a new encrypt pub key serializer.
- encryptUri(String) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt uri.
- encryptUri(String) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Encrypts a value and applies an additional Base64 layer, making the result safe for embedding in URL path segments or query parameters.
- encryptUri(String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Encrypt uri.
- encryptUri(String, CryptoType) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt uri.
- encryptUri(String, String) - Method in class com.bld.crypto.aes.CryptoAesUtils
-
Encrypt uri.
- encryptUri(String, String) - Method in class com.bld.crypto.bean.CryptoKeyUtils
-
Encrypts a value and then encodes the result with an additional Base64 layer so that it is safe for use in URL path segments or query parameters.
- encryptUri(String, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Encrypt uri.
- encryptUri(String, String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Encrypt uri.
- encryptValue(String) - Method in class com.bld.crypto.aes.formatter.CryptoAesFormatter
-
Encrypt value.
- encryptValue(String) - Method in class com.bld.crypto.aes.serializer.EncryptAesSerializer
-
Encrypt value.
- encryptValue(String) - Method in class com.bld.crypto.formatter.CryptoFormatter
-
Encrypts the given plain-text word using the concrete encryption strategy.
- encryptValue(String) - Method in class com.bld.crypto.hmac.formatter.CryptoHmacFormatter
- encryptValue(String) - Method in class com.bld.crypto.hmac.serializer.EncryptHmacSerializer
- encryptValue(String) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt value.
- encryptValue(String) - Method in class com.bld.crypto.jks.formatter.CryptoJksFormatter
-
Wraps the plain-text value in a
{key, value}JSON envelope and encrypts it, aligning with the Jackson serializer behaviour. - encryptValue(String) - Method in class com.bld.crypto.jks.serializer.EncryptJksSerializer
-
Encrypt value.
- encryptValue(String) - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Encrypts a plain-text string using the recipient's X25519 public key.
- encryptValue(String) - Method in class com.bld.crypto.pkcs12.formatter.CryptoPkcs12Formatter
-
Wraps the plain-text value in a
{key, value}JSON envelope and encrypts it using the PKCS12 public key, aligning with the Jackson serializer behaviour. - encryptValue(String) - Method in class com.bld.crypto.pkcs12.serializer.EncryptPkcs12Serializer
-
Wraps the plain-text value in a
{key, value}JSON envelope and encrypts it. - encryptValue(String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Encrypt value.
- encryptValue(String) - Method in class com.bld.crypto.pubkey.formatter.CryptoPubKeyFormatter
-
Encrypt value.
- encryptValue(String) - Method in class com.bld.crypto.pubkey.serializer.EncryptPubKeySerializer
-
Encrypt value.
- encryptValue(String) - Method in class com.bld.crypto.serializer.EncryptCertificateSerializer
-
Encrypts the given plain-text string.
- encryptValue(String, CryptoType) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt value.
- encryptValue(String, String) - Method in class com.bld.crypto.aes.CryptoAesUtils
-
Encrypt value.
- encryptValue(String, String) - Method in class com.bld.crypto.bean.CryptoKeyUtils
-
Encrypts a plain-text value using the named key.
- encryptValue(String, String) - Method in class com.bld.crypto.jks.CryptoJksUtils
-
Encrypt value.
- encryptValue(String, String) - Method in class com.bld.crypto.pubkey.CryptoMapPublicKeyUtils
-
Encrypt value.
- encryptValue(String, String) - Method in class com.bld.crypto.pubkey.CryptoPublicKeyUtils
-
Encrypt value.
- encryptValue(String, Key, InstanceType) - Static method in class com.bld.crypto.bean.CryptoKeyUtils
-
Encrypts a plain-text string using the supplied key and algorithm, then encodes the resulting bytes as a Base64 string.
F
- fieldName - Variable in class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
The name of the JSON field currently being deserialised (used for error messages).
- fieldType - Variable in class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
The raw class of the target field type.
G
- getAlgorithm() - Method in class com.bld.crypto.hmac.config.data.CryptoHmacSecret
- getAlgorithm() - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- getAlias() - Method in class com.bld.crypto.key.KeyProperties
- getCipher(int, Key, InstanceType) - Static method in class com.bld.crypto.bean.CryptoKeyUtils
-
Creates and initialises a
Cipherinstance for the given mode and key. - getFieldTypes() - Method in class com.bld.crypto.aes.formatter.CryptoAesAnnotationFormatterFactory
-
Gets the field types.
- getFieldTypes() - Method in class com.bld.crypto.hmac.formatter.CryptoHmacAnnotationFormatterFactory
- getFieldTypes() - Method in class com.bld.crypto.jks.formatter.CryptoJksAnnotationFormatterFactory
-
Gets the field types.
- getFieldTypes() - Method in class com.bld.crypto.pkcs12.formatter.CryptoPkcs12AnnotationFormatterFactory
-
Returns the set of field types supported by this factory.
- getFieldTypes() - Method in class com.bld.crypto.pubkey.formatter.CryptoPubKeyAnnotationFormatterFactory
-
Gets the field types.
- getFile() - Method in class com.bld.crypto.key.KeyProperties
- getInstanceJks() - Method in class com.bld.crypto.key.KeyProperties
- getInstanceSignature() - Method in class com.bld.crypto.signature.config.properties.SignatureKeyProperties
- getKeyLength() - Method in class com.bld.crypto.aes.config.data.Aes
-
Gets the key length.
- getKeyLength() - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- getKeys() - Method in class com.bld.crypto.aes.config.data.AesProperties
-
Gets the keys.
- getKeys() - Method in class com.bld.crypto.pubkey.config.data.PublicKeyProperties
-
Gets the keys.
- getMatchOutcome(ConditionContext, AnnotatedTypeMetadata) - Method in class com.bld.crypto.aes.config.AesConditional
-
Gets the match outcome.
- getMatchOutcome(ConditionContext, AnnotatedTypeMetadata) - Method in class com.bld.crypto.hmac.config.HmacConditional
- getMatchOutcome(ConditionContext, AnnotatedTypeMetadata) - Method in class com.bld.crypto.pubkey.config.PubKeyConditional
-
Gets the match outcome.
- getName() - Method in class com.bld.crypto.bean.CryptoKeyData
-
Returns the logical name of the cryptographic key.
- getOrder() - Method in class com.bld.crypto.openapi.CryptoModelConverter
- getParser(CryptoAes, Class<?>) - Method in class com.bld.crypto.aes.formatter.CryptoAesAnnotationFormatterFactory
-
Gets the parser.
- getParser(CryptoHmac, Class<?>) - Method in class com.bld.crypto.hmac.formatter.CryptoHmacAnnotationFormatterFactory
- getParser(CryptoJks, Class<?>) - Method in class com.bld.crypto.jks.formatter.CryptoJksAnnotationFormatterFactory
-
Gets the parser.
- getParser(CryptoPkcs12, Class<?>) - Method in class com.bld.crypto.pkcs12.formatter.CryptoPkcs12AnnotationFormatterFactory
-
Returns a
CryptoPkcs12Formatterconfigured to decrypt values on parse. - getParser(CryptoPubKey, Class<?>) - Method in class com.bld.crypto.pubkey.formatter.CryptoPubKeyAnnotationFormatterFactory
-
Gets the parser.
- getPassword() - Method in class com.bld.crypto.aes.config.data.Aes
-
Gets the password.
- getPassword() - Method in class com.bld.crypto.key.KeyProperties
- getPrinter(CryptoAes, Class<?>) - Method in class com.bld.crypto.aes.formatter.CryptoAesAnnotationFormatterFactory
-
Gets the printer.
- getPrinter(CryptoHmac, Class<?>) - Method in class com.bld.crypto.hmac.formatter.CryptoHmacAnnotationFormatterFactory
- getPrinter(CryptoJks, Class<?>) - Method in class com.bld.crypto.jks.formatter.CryptoJksAnnotationFormatterFactory
-
Gets the printer.
- getPrinter(CryptoPkcs12, Class<?>) - Method in class com.bld.crypto.pkcs12.formatter.CryptoPkcs12AnnotationFormatterFactory
-
Returns a
CryptoPkcs12Formatterconfigured to encrypt values on print. - getPrinter(CryptoPubKey, Class<?>) - Method in class com.bld.crypto.pubkey.formatter.CryptoPubKeyAnnotationFormatterFactory
-
Gets the printer.
- getPrivateKey() - Method in class com.bld.crypto.key.JksKey
-
Gets the private key.
- getPublicKey() - Method in class com.bld.crypto.jks.CryptoJksUtils
- getPublicKey() - Method in class com.bld.crypto.key.JksKey
-
Gets the public key.
- getPublicKey() - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Returns the X25519 public key from the loaded key pair.
- getPublicKey() - Method in class com.bld.crypto.signature.SignatureKeyUtils
- getPublicKey(String) - Method in class com.bld.crypto.pubkey.config.data.CipherPublicKeys
-
Gets the public key.
- getPublicKey(String, InstanceType) - Static method in class com.bld.crypto.commons.KeyUtility
-
Decodes a Base64-encoded X.509 public key and returns a
PublicKeyfor the specified algorithm. - getSalt() - Method in class com.bld.crypto.aes.config.data.Aes
-
Gets the salt.
- getSalt() - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- getSecret() - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- getSecretKey() - Method in class com.bld.crypto.hmac.config.data.CryptoHmacSecret
- getSecretKey(String) - Method in class com.bld.crypto.aes.config.data.CipherAesSecret
-
Gets the secret key.
H
- HmacConditional - Class in com.bld.crypto.hmac.config
-
Spring condition that activates the HMAC module only when
com.bld.crypto.hmac.secretis present and non-blank. - HmacConditional() - Constructor for class com.bld.crypto.hmac.config.HmacConditional
- HmacConfiguration - Class in com.bld.crypto.hmac.config
-
Spring configuration for the HMAC module.
- HmacConfiguration() - Constructor for class com.bld.crypto.hmac.config.HmacConfiguration
- HmacFormatterConfiguration - Class in com.bld.crypto.hmac.config
-
Registers the
CryptoHmacAnnotationFormatterFactorywith Spring MVC so that@CryptoHmac-annotated@PathVariableand@RequestParamparameters are automatically signed and verified. - HmacFormatterConfiguration() - Constructor for class com.bld.crypto.hmac.config.HmacFormatterConfiguration
- HmacProperties - Class in com.bld.crypto.hmac.config.data
-
Configuration properties for the HMAC module.
- HmacProperties() - Constructor for class com.bld.crypto.hmac.config.data.HmacProperties
I
- InstanceType - Enum Class in com.bld.crypto.type
-
Enumeration of the cryptographic algorithm identifiers used when obtaining a
CipherorKeyFactoryinstance. - isUrl() - Method in class com.bld.crypto.bean.CryptoKeyData
-
Returns whether the encrypted value must be URL-safe Base64-encoded.
J
- JksFormatterConfiguration - Class in com.bld.crypto.jks.config
-
The Class JksFormatterConfiguration.
- JksFormatterConfiguration() - Constructor for class com.bld.crypto.jks.config.JksFormatterConfiguration
- JksKey - Class in com.bld.crypto.key
-
The Class CipherJks.
- JksKey(String, String, InstanceType) - Constructor for class com.bld.crypto.key.JksKey
- JksKey(PrivateKey, PublicKey) - Constructor for class com.bld.crypto.key.JksKey
-
Instantiates a new cipher jks.
- JksKeyProperties - Class in com.bld.crypto.jks.config.properties
-
The Class JksProperties.
- JksKeyProperties() - Constructor for class com.bld.crypto.jks.config.properties.JksKeyProperties
K
- KeyProperties - Class in com.bld.crypto.key
- KeyProperties() - Constructor for class com.bld.crypto.key.KeyProperties
- KeyUtility - Class in com.bld.crypto.commons
-
Utility class that provides static helper methods for converting raw key material (Base64-encoded DER bytes) into
PublicKeyinstances. - KeyUtility() - Constructor for class com.bld.crypto.commons.KeyUtility
L
- listFieldType - Variable in class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
The element type when the field is a
Collectionor array.
O
- objMapper - Variable in class com.bld.crypto.bean.CryptoKeyUtils
-
Jackson
ObjectMapperinjected by Spring for JSON serialization/deserialization. - objMapper - Variable in class com.bld.crypto.deserializer.DecryptCertificateDeserializer
-
Jackson
ObjectMapperused to deserialise POJO values from JSON after decryption. - objMapper - Variable in class com.bld.crypto.formatter.CryptoFormatter
-
Jackson
ObjectMapperused for JSON serialisation/deserialisation of POJO values. - objMapper - Variable in class com.bld.crypto.serializer.EncryptCertificateSerializer
-
Jackson
ObjectMapperused to serialise POJO values to JSON before encryption.
P
- parse(String, Locale) - Method in class com.bld.crypto.formatter.CryptoFormatter
-
Decrypts the given cipher-text string and converts the result to the target field type.
- Pkcs12FormatterConfiguration - Class in com.bld.crypto.pkcs12.config
-
Spring MVC
Configurationthat registers theCryptoPkcs12AnnotationFormatterFactoryso that@CryptoPkcs12-annotated request parameters are transparently encrypted/decrypted during Spring MVC binding. - Pkcs12FormatterConfiguration() - Constructor for class com.bld.crypto.pkcs12.config.Pkcs12FormatterConfiguration
- Pkcs12KeyProperties - Class in com.bld.crypto.pkcs12.config.properties
-
Configuration properties for the PKCS12 hybrid-encryption keystore.
- Pkcs12KeyProperties() - Constructor for class com.bld.crypto.pkcs12.config.properties.Pkcs12KeyProperties
- print(T, Locale) - Method in class com.bld.crypto.formatter.CryptoFormatter
-
Encrypts the given value and returns its cipher-text string representation.
- privateKey - Enum constant in enum class com.bld.crypto.type.CryptoType
-
Selects the private key for the operation.
- PubKeyConditional - Class in com.bld.crypto.pubkey.config
-
The Class PubKeyConditional.
- PubKeyConditional() - Constructor for class com.bld.crypto.pubkey.config.PubKeyConditional
- PubKeyFormatterConfiguration - Class in com.bld.crypto.pubkey.config
-
The Class PubKeyFormatterConfiguration.
- PubKeyFormatterConfiguration() - Constructor for class com.bld.crypto.pubkey.config.PubKeyFormatterConfiguration
- publicKey - Enum constant in enum class com.bld.crypto.type.CryptoType
-
Selects the public key for the operation.
- publicKey() - Method in class com.bld.crypto.jks.CryptoJksUtils
- publicKey() - Method in class com.bld.crypto.key.JksKey
- publicKey() - Method in class com.bld.crypto.pkcs12.CryptoPkcs12Utils
-
Returns the Base64-encoded X.509 DER representation of the X25519 public key.
- publicKey() - Method in class com.bld.crypto.signature.SignatureKeyUtils
- PublicKeyProperties - Class in com.bld.crypto.pubkey.config.data
-
The Class PublicKeyProperties.
- PublicKeyProperties(Map<String, Resource>) - Constructor for class com.bld.crypto.pubkey.config.data.PublicKeyProperties
-
Instantiates a new public key properties.
R
- resolve(AnnotatedType, ModelConverterContext, Iterator<ModelConverter>) - Method in class com.bld.crypto.openapi.CryptoModelConverter
- RSA - Enum constant in enum class com.bld.crypto.type.InstanceType
-
RSA asymmetric algorithm (used for JKS and public-key strategies).
S
- serialize(T, JsonGenerator, SerializerProvider) - Method in class com.bld.crypto.serializer.EncryptCertificateSerializer
-
Serialises and encrypts the value, writing the result as a JSON string (or JSON array when the value is a
Collectionor array). - setAlgorithm(String) - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- setAlias(String) - Method in class com.bld.crypto.key.KeyProperties
- setFile(Resource) - Method in class com.bld.crypto.key.KeyProperties
- setInstanceJks(String) - Method in class com.bld.crypto.key.KeyProperties
- setInstanceSignature(String) - Method in class com.bld.crypto.signature.config.properties.SignatureKeyProperties
- setKeyLength(Integer) - Method in class com.bld.crypto.aes.config.data.Aes
-
Sets the key length.
- setKeyLength(Integer) - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- setPassword(String) - Method in class com.bld.crypto.aes.config.data.Aes
-
Sets the password.
- setPassword(String) - Method in class com.bld.crypto.key.KeyProperties
- setSalt(String) - Method in class com.bld.crypto.aes.config.data.Aes
-
Sets the salt.
- setSalt(String) - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- setSecret(String) - Method in class com.bld.crypto.hmac.config.data.HmacProperties
- sign(String) - Method in class com.bld.crypto.signature.SignatureKeyUtils
- sign(String, PrivateKey, String) - Static method in class com.bld.crypto.signature.SignatureKeyUtils
- SignatureConfiguration - Class in com.bld.crypto.signature.config
-
The Class EnableCryptoJksConfiguration.
- SignatureConfiguration() - Constructor for class com.bld.crypto.signature.config.SignatureConfiguration
- SignatureKeyProperties - Class in com.bld.crypto.signature.config.properties
-
The Class JksProperties.
- SignatureKeyProperties() - Constructor for class com.bld.crypto.signature.config.properties.SignatureKeyProperties
- SignatureKeyUtils - Class in com.bld.crypto.signature
- SignatureKeyUtils(JksKey, SignatureKeyProperties) - Constructor for class com.bld.crypto.signature.SignatureKeyUtils
- signUri(String, String) - Method in class com.bld.crypto.hmac.CryptoHmacUtils
-
Signs
valueand returns a URL-safe Base64 token (no padding). - signValue(String, String) - Method in class com.bld.crypto.hmac.CryptoHmacUtils
-
Signs
valueand returns a standard Base64 token. - size() - Method in enum class com.bld.crypto.type.AesSizeType
-
Returns the key size in bytes.
- SPLIT_STRING - Static variable in class com.bld.crypto.jks.CryptoJksUtils
-
The Constant SPLIT_STRING.
- sz16 - Enum constant in enum class com.bld.crypto.type.AesSizeType
-
128-bit AES key (16 bytes).
- sz24 - Enum constant in enum class com.bld.crypto.type.AesSizeType
-
192-bit AES key (24 bytes).
- sz32 - Enum constant in enum class com.bld.crypto.type.AesSizeType
-
256-bit AES key (32 bytes).
U
- url() - Element in annotation interface com.bld.crypto.aes.annotation.CryptoAes
-
Url.
- url() - Element in annotation interface com.bld.crypto.hmac.annotation.CryptoHmac
-
When
truethe token uses URL-safe Base64 encoding (no padding), suitable for path segments or query parameters. - url() - Element in annotation interface com.bld.crypto.jks.annotation.CryptoJks
-
Url.
- url() - Element in annotation interface com.bld.crypto.pkcs12.annotation.CryptoPkcs12
-
When
truethe encrypted output receives an additional Base64 encoding layer so that it is safe for use in URL path segments or query parameters. - url() - Element in annotation interface com.bld.crypto.pubkey.annotations.CryptoPubKey
-
Url.
- url() - Element in annotation interface com.bld.crypto.pubkey.annotations.DecryptPubKey
-
Url.
- url() - Element in annotation interface com.bld.crypto.pubkey.annotations.EncryptPubKey
-
Url.
V
- value() - Element in annotation interface com.bld.crypto.aes.annotation.CryptoAes
-
Value.
- value() - Element in annotation interface com.bld.crypto.hmac.annotation.CryptoHmac
-
Logical field identifier embedded inside the signed token.
- value() - Element in annotation interface com.bld.crypto.jks.annotation.CryptoJks
- value() - Element in annotation interface com.bld.crypto.pkcs12.annotation.CryptoPkcs12
-
Logical key identifier embedded inside the encrypted payload.
- value() - Element in annotation interface com.bld.crypto.pubkey.annotations.CryptoPubKey
-
Value.
- value() - Element in annotation interface com.bld.crypto.pubkey.annotations.DecryptPubKey
-
Value.
- value() - Element in annotation interface com.bld.crypto.pubkey.annotations.EncryptPubKey
-
Value.
- valueOf(String) - Static method in enum class com.bld.crypto.type.AesSizeType
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class com.bld.crypto.type.CryptoType
-
Returns the enum constant of this class with the specified name.
- valueOf(String) - Static method in enum class com.bld.crypto.type.InstanceType
-
Returns the enum constant of this class with the specified name.
- values() - Static method in enum class com.bld.crypto.type.AesSizeType
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class com.bld.crypto.type.CryptoType
-
Returns an array containing the constants of this enum class, in the order they are declared.
- values() - Static method in enum class com.bld.crypto.type.InstanceType
-
Returns an array containing the constants of this enum class, in the order they are declared.
- verify(String, String) - Method in class com.bld.crypto.signature.SignatureKeyUtils
- verify(PublicKey, String, String, String) - Static method in class com.bld.crypto.signature.SignatureKeyUtils
- verifyUri(String, String) - Method in class com.bld.crypto.hmac.CryptoHmacUtils
-
Verifies a URL-safe Base64 token and returns the original plain-text value.
- verifyValue(String, String) - Method in class com.bld.crypto.hmac.CryptoHmacUtils
-
Verifies a standard Base64 token and returns the original plain-text value.
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form